@@ -135,21 +135,25 @@ def gen_ip_image(ip, sim_job, fsoc_core_name, fsoc_core_flist_path):
         prep_ip_for_gen_image(dep, sim_job)
     prep_ip_for_gen_image(ip, sim_job)
     
-    timestamp_start = common.timestamp()
-    log_file_path = gen_image_flist(ip, ip.vendor, ip.name, flist_path, sim_job, ip.is_local)
-    if not sim_job.dry_run:
-        timestamp_end = common.timestamp()
-        errors = scan_gen_image_log_file_for_errors(log_file_path, sim_job)
-        if len(errors):
-            common.error("Errors during compilation/elaboration of IP '" + ip_str + "':")
-            for error in errors:
-                common.error("  " + error)
-            sim.kill_progress_bar()
-            common.fatal("Stopping due to compilation/elaborationn errors. Full log: " + log_file_path)
-        log_gen_image_history_ip(ip, log_file_path, sim_job, timestamp_start, timestamp_end)
-        ip.is_compiled  [sim_job.simulator] = True
-        ip.is_elaborated[sim_job.simulator] = True
-    return log_file_path
+    if sim_job.simulator == common.simulators_enum.VIVADO:
+        pass
+        
+    else:
+        timestamp_start = common.timestamp()
+        log_file_path = gen_image_flist(ip, ip.vendor, ip.name, flist_path, sim_job, ip.is_local)
+        if not sim_job.dry_run:
+            timestamp_end = common.timestamp()
+            errors = scan_gen_image_log_file_for_errors(log_file_path, sim_job)
+            if len(errors):
+                common.error("Errors during compilation/elaboration of IP '" + ip_str + "':")
+                for error in errors:
+                    common.error("  " + error)
+                sim.kill_progress_bar()
+                common.fatal("Stopping due to compilation/elaborationn errors. Full log: " + log_file_path)
+            log_gen_image_history_ip(ip, log_file_path, sim_job, timestamp_start, timestamp_end)
+            ip.is_compiled  [sim_job.simulator] = True
+            ip.is_elaborated[sim_job.simulator] = True
+        return log_file_path
 
 
 def prep_ip_for_gen_image(ip, sim_job):
@@ -1333,11 +1337,12 @@ def invoke_fsoc(ip, core, sim_job):
     fsc_cores_root = [core.dir]
     
     
+    fusesoc.main.init_logging(False, False)
+    fsc_cfg = fusesoc.main.Config()
+    fsc_cm  = fusesoc.main.init_coremanager(fsc_cfg, fsc_cores_root)
+    fusesoc.main.run(fsc_cm, fsc_args)
+    
     try:
-        fusesoc.main.init_logging(False, False)
-        fsc_cfg = fusesoc.main.Config()
-        fsc_cm  = fusesoc.main.init_coremanager(fsc_cfg, fsc_cores_root)
-        fusesoc.main.run(fsc_cm, fsc_args)
         file_path_partial_name = re.sub(r':', '_', core.name)
         eda_file_dir = cfg.fsoc_dir + "/" + core.sname + "/sim-xsim"
         eda_file_path = eda_file_dir + "/" + file_path_partial_name + "_0.eda.yml"
