@@ -110,6 +110,22 @@ def install_ip_dep_list(ip, ip_list, global_install, username="", password=""):
         update_lock_file(ip, versions)
 
 
+def install_ip_list(ip, ip_list, global_install, username="", password=""):
+    versions = {}
+    if len(ip_list) > 0:
+        #with alive_bar(len(ip_list), bar = 'smooth') as bar:
+        with tqdm(ip_list) as pbar:
+            for dep_ip in ip_list:
+                vendor = ip.vendor
+                name = ip.name
+                ip_str = f"{vendor}/{name}"
+                pbar.set_description(ip_str)
+                versions[ip_str] = install_ip(vendor, name, global_install, username="", password="")
+                pbar.update(1)
+        cache.scan_and_load_ip_metadata()
+        update_lock_file(ip, versions)
+
+
 def install_ip_and_deps(vendor, name, global_install, username="", password=""):
     ip = {}
     if vendor == "":
@@ -122,6 +138,11 @@ def install_ip_and_deps(vendor, name, global_install, username="", password=""):
         cache.scan_and_load_ip_metadata()
         ip = cache.get_ip(vendor, name)
     
+    #deps_to_install = ip.get_ordered_install_deps()
+    #common.info(f"Installing {len(deps_to_install)} dependencies")
+    #install_ip_list(ip, deps_to_install, global_install, username, password)
+    #cache.scan_and_load_ip_metadata()
+    
     deps_to_install = ip.get_deps_to_install()
     while len(deps_to_install) > 0:
         common.info(f"Installing {len(deps_to_install)} dependencies")
