@@ -730,7 +730,7 @@ def print_end_of_simulation_message(ip, sim_job):
         elif sim_job.simulator == common.simulators_enum.VCS:
             common.info("* Waveforms: $MIO_VCS_HOME/dve -gui " + results_path + "/waves.wdb &")
         elif sim_job.simulator == common.simulators_enum.METRICS:
-            common.info(f"* Waveforms: $MIO_METRICS_HOME/mdc view wave {sim_job.results_dir_name}.vcd &")
+            common.info(f"* Waveforms: gtkwave {results_path}/waves.vcd &")
         elif sim_job.simulator == common.simulators_enum.XCELIUM:
             common.info("* Waveforms: $MIO_XCELIUM_HOME/simvision -gui " + results_path + "/waves.wdb &")
         elif sim_job.simulator == common.simulators_enum.QUESTA:
